From 76d0c1b59e8f8c080ea502f0ad54527a5a0bfab3 Mon Sep 17 00:00:00 2001
From: Melanie Plageman <melanieplageman@gmail.com>
Date: Mon, 25 Mar 2024 18:02:09 -0400
Subject: [PATCH v9 03/21] Rename PruneState->snapshotConflictHorizon to
 latest_xid_removed

In anticipation of combining pruning and freezing and emitting a single
WAL record, rename PruneState->snapshotConflictHorizon to
latest_xid_removed. After pruning and freezing, we will choose a
combined record snapshot conflict horizon taking into account both
values.
---
 src/backend/access/heap/pruneheap.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/backend/access/heap/pruneheap.c b/src/backend/access/heap/pruneheap.c
index 29c3c98b0e7..7d7e1d2744c 100644
--- a/src/backend/access/heap/pruneheap.c
+++ b/src/backend/access/heap/pruneheap.c
@@ -35,7 +35,7 @@ typedef struct
 	bool		mark_unused_now;
 
 	TransactionId new_prune_xid;	/* new prune hint value for page */
-	TransactionId snapshotConflictHorizon;	/* latest xid removed */
+	TransactionId latest_xid_removed;
 	int			nredirected;	/* numbers of entries in arrays below */
 	int			ndead;
 	int			nunused;
@@ -238,7 +238,7 @@ heap_page_prune(Relation relation, Buffer buffer,
 	prstate.new_prune_xid = InvalidTransactionId;
 	prstate.vistest = vistest;
 	prstate.mark_unused_now = mark_unused_now;
-	prstate.snapshotConflictHorizon = InvalidTransactionId;
+	prstate.latest_xid_removed = InvalidTransactionId;
 	prstate.nredirected = prstate.ndead = prstate.nunused = 0;
 	memset(prstate.marked, 0, sizeof(prstate.marked));
 
@@ -367,7 +367,7 @@ heap_page_prune(Relation relation, Buffer buffer,
 		if (RelationNeedsWAL(relation))
 		{
 			log_heap_prune_and_freeze(relation, buffer,
-									  prstate.snapshotConflictHorizon,
+									  prstate.latest_xid_removed,
 									  true, reason,
 									  NULL, 0,
 									  prstate.redirected, prstate.nredirected,
@@ -501,7 +501,7 @@ heap_prune_chain(Buffer buffer, OffsetNumber rootoffnum,
 			{
 				heap_prune_record_unused(prstate, rootoffnum);
 				HeapTupleHeaderAdvanceConflictHorizon(htup,
-													  &prstate->snapshotConflictHorizon);
+													  &prstate->latest_xid_removed);
 				ndeleted++;
 			}
 
@@ -647,7 +647,7 @@ heap_prune_chain(Buffer buffer, OffsetNumber rootoffnum,
 		{
 			latestdead = offnum;
 			HeapTupleHeaderAdvanceConflictHorizon(htup,
-												  &prstate->snapshotConflictHorizon);
+												  &prstate->latest_xid_removed);
 		}
 		else if (!recent_dead)
 			break;
-- 
2.40.1

